@@ -43,9 +43,9 @@ def file_clean(file_folder, n=2):
     n : TYPE, optional
         DESCRIPTION. The default is 50.
     """
-    file_list = [os.path.join(file_folder, i) for i in get_file_list(file_folder)]
+    if get_file_list(file_folder):
+        file_list = [os.path.join(file_folder, i) for i in get_file_list(file_folder)]
     
-    clean_list = filter(lambda x: datetime.fromtimestamp(os.path.getctime(x)).year == (datetime.now().year - n), file_list)
-    print(list(clean_list))
-    for i in clean_list:
-        os.remove(i)
+        clean_list = filter(lambda x: datetime.fromtimestamp(os.path.getctime(x)).year == (datetime.now().year - n), file_list)
+        for i in clean_list:
+            os.remove(i)
