@@ -4,8 +4,10 @@ import settings
 
 if __name__ == "__main__":
     # 获取报表保存
-    data = custom.report()
-    excel_format(data_tuple=data, filename=settings.ATTACHES[0])
+    wb = custom.workbook()
+
+    # 格式化本地文件
+    excel_format(data_tuple=wb, filename=settings.ATTACHES[0])
 
     # 发送邮件
     try:
@@ -15,7 +17,7 @@ if __name__ == "__main__":
                   password=settings.PASSWORD,
                   receivers=settings.RECEIVERS,
                   subject=settings.SUBJECT,
-                  attaches=[settings.ATTACHES], content=settings.CONTENT)
+                  attaches=settings.ATTACHES, content=settings.CONTENT)
     except Exception as e:
         send_mail(host=settings.HOST,
                   port=settings.PORT,
