@@ -3,14 +3,15 @@ HOST = ''
 PORT = 994
 USER = ''
 PASSWORD = ''
-RECEIVERS = ''
-WARNING_USER = ''
+RECEIVERS = []
+WARNING_USER = []
 SUBJECT = ''
 CONTENT = ''
 
 # 邮箱可选参数
 # 附件名
 ATTACHES = []
+SHEET_NAMES = []
 # 抄件人
 # CARBON_COPY = []
 # MASK
